/**************************************************************
 *** RHmm package
 ***                                                         
 *** File: StdAfxRHmm.h 
 ***                                                         
 *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
 *** Author: Sebastian BAUER <sebastian.bauer@charite.de>
 ***                                                         
 **************************************************************/

#include "OTMathUtil.h"
#include "LogProb.h"
#include "SamplesUtil.h"
#include "MultivariateNormalUtil.h"
#include "Hmm.h"
#include "cCyclicVector.h"
#include "cInParam.h"
#include "cBaumWelchInParam.h"
#include "cHmm.h"
#include "cBaumWelch.h"
#include "cLogBaumWelch.h"
#include "cDistribution.h"
#include "cDiscrete.h"
#include "cMixtMultivariateNormal.h"
#include "cMixtUnivariateNormal.h"
#include "cMultivariateNormal.h"
#include "cUnivariateNormal.h"
#include "cHmmFit.h"
#include "cViterbi.h"
#include "cRUtils.h"
#include "REquivalents.h"
#include "RHmm.h"

